@@ -1,17 +1,17 @@
 // SPDX-License-Identifier: BSD-2-Clause
 /* Copyright (C) 2019 - 2021 Intel Corporation. */
 
+#include <memkind/internal/heap_manager.h>
+#include <memkind/internal/memkind_arena.h>
 #include <memkind/internal/memkind_bitmask.h>
 #include <memkind/internal/memkind_dax_kmem.h>
 #include <memkind/internal/memkind_default.h>
-#include <memkind/internal/memkind_arena.h>
 #include <memkind/internal/memkind_log.h>
-#include <memkind/internal/heap_manager.h>
 
 #include "config.h"
-#include <pthread.h>
-#include <numa.h>
 #include <errno.h>
+#include <numa.h>
+#include <pthread.h>
 
 struct dax_numanode_t {
     int init_err;
@@ -19,7 +19,8 @@ struct dax_numanode_t {
 };
 
 static struct dax_numanode_t memkind_dax_kmem_numanode_g[NODE_VARIANT_MAX_EXT];
-static pthread_once_t memkind_dax_kmem_numanode_once_g[NODE_VARIANT_MAX_EXT] = {PTHREAD_ONCE_INIT};
+static pthread_once_t memkind_dax_kmem_numanode_once_g[NODE_VARIANT_MAX_EXT] = {
+    PTHREAD_ONCE_INIT};
 
 static void memkind_dax_kmem_closest_numanode_init(void);
 static void memkind_dax_kmem_preferred_closest_numanode_init(void);
@@ -27,21 +28,19 @@ static void memkind_dax_kmem_all_numanode_init(void);
 #ifdef MEMKIND_DAXCTL_KMEM
 #include <daxctl/libdaxctl.h>
 #ifndef daxctl_region_foreach_safe
-#define daxctl_region_foreach_safe(ctx, region, _region) \
-    for (region = daxctl_region_get_first(ctx), \
-         _region = region ? daxctl_region_get_next(region) : NULL; \
-         region != NULL; \
-         region = _region, \
+#define daxctl_region_foreach_safe(ctx, region, _region)                       \
+    for (region = daxctl_region_get_first(ctx),                                \
+        _region = region ? daxctl_region_get_next(region) : NULL;              \
+         region != NULL; region = _region,                                     \
         _region = _region ? daxctl_region_get_next(_region) : NULL)
 #endif
 
 #ifndef daxctl_dev_foreach_safe
-#define daxctl_dev_foreach_safe(region, dev, _dev) \
-    for (dev = daxctl_dev_get_first(region), \
-         _dev = dev ? daxctl_dev_get_next(dev) : NULL; \
-         dev != NULL; \
-         dev = _dev, \
-        _dev = _dev ? daxctl_dev_get_next(_dev) : NULL)
+#define daxctl_dev_foreach_safe(region, dev, _dev)                             \
+    for (dev = daxctl_dev_get_first(region),                                   \
+        _dev = dev ? daxctl_dev_get_next(dev) : NULL;                          \
+         dev != NULL;                                                          \
+         dev = _dev, _dev = _dev ? daxctl_dev_get_next(_dev) : NULL)
 #endif
 
 static int get_dax_kmem_nodemask(struct bitmask **dax_kmem_node_mask)
@@ -61,8 +60,10 @@ static int get_dax_kmem_nodemask(struct bitmask **dax_kmem_node_mask)
     if (rc < 0)
         goto free_mask;
 
-    daxctl_region_foreach_safe(ctx, region, _region) {
-        daxctl_dev_foreach_safe(region, dev, _dev) {
+    daxctl_region_foreach_safe(ctx, region, _region)
+    {
+        daxctl_dev_foreach_safe(region, dev, _dev)
+        {
             struct daxctl_memory *mem = daxctl_dev_get_memory(dev);
             if (mem) {
                 numa_bitmask_setbit(*dax_kmem_node_mask,
@@ -105,44 +106,51 @@ static int memkind_dax_kmem_check_available(struct memkind *kind)
 }
 
 static int memkind_dax_kmem_get_mbind_nodemask(struct memkind *kind,
-                                               unsigned long *nodemask, unsigned long maxnode)
+                                               unsigned long *nodemask,
+                                               unsigned long maxnode)
 {
-    struct dax_numanode_t *g = &memkind_dax_kmem_numanode_g[NODE_VARIANT_MULTIPLE];
+    struct dax_numanode_t *g =
+        &memkind_dax_kmem_numanode_g[NODE_VARIANT_MULTIPLE];
     pthread_once(&memkind_dax_kmem_numanode_once_g[NODE_VARIANT_MULTIPLE],
                  memkind_dax_kmem_closest_numanode_init);
     if (MEMKIND_LIKELY(!g->init_err)) {
-        g->init_err = set_bitmask_for_current_numanode(nodemask, maxnode, g->numanode);
+        g->init_err =
+            set_bitmask_for_current_numanode(nodemask, maxnode, g->numanode);
     }
     return g->init_err;
 }
 
-static int memkind_dax_kmem_get_preferred_mbind_nodemask(struct memkind *kind,
-                                                         unsigned long *nodemask, unsigned long maxnode)
+static int memkind_dax_kmem_get_preferred_mbind_nodemask(
+    struct memkind *kind, unsigned long *nodemask, unsigned long maxnode)
 {
-    struct dax_numanode_t *g = &memkind_dax_kmem_numanode_g[NODE_VARIANT_SINGLE];
+    struct dax_numanode_t *g =
+        &memkind_dax_kmem_numanode_g[NODE_VARIANT_SINGLE];
     pthread_once(&memkind_dax_kmem_numanode_once_g[NODE_VARIANT_SINGLE],
                  memkind_dax_kmem_preferred_closest_numanode_init);
     if (MEMKIND_LIKELY(!g->init_err)) {
-        g->init_err = set_bitmask_for_current_numanode(nodemask, maxnode, g->numanode);
+        g->init_err =
+            set_bitmask_for_current_numanode(nodemask, maxnode, g->numanode);
     }
     return g->init_err;
 }
 
-MEMKIND_EXPORT int memkind_dax_kmem_all_get_mbind_nodemask(struct memkind *kind,
-                                                           unsigned long *nodemask, unsigned long maxnode)
+MEMKIND_EXPORT int memkind_dax_kmem_all_get_mbind_nodemask(
+    struct memkind *kind, unsigned long *nodemask, unsigned long maxnode)
 {
     struct dax_numanode_t *g = &memkind_dax_kmem_numanode_g[NODE_VARIANT_ALL];
     pthread_once(&memkind_dax_kmem_numanode_once_g[NODE_VARIANT_ALL],
                  memkind_dax_kmem_all_numanode_init);
     if (MEMKIND_LIKELY(!g->init_err)) {
-        g->init_err = set_bitmask_for_current_numanode(nodemask, maxnode, g->numanode);
+        g->init_err =
+            set_bitmask_for_current_numanode(nodemask, maxnode, g->numanode);
     }
     return g->init_err;
 }
 
 static void memkind_dax_kmem_closest_numanode_init(void)
 {
-    struct dax_numanode_t *g = &memkind_dax_kmem_numanode_g[NODE_VARIANT_MULTIPLE];
+    struct dax_numanode_t *g =
+        &memkind_dax_kmem_numanode_g[NODE_VARIANT_MULTIPLE];
     g->numanode = NULL;
     g->init_err = set_closest_numanode(memkind_dax_kmem_get_nodemask,
                                        &g->numanode, NODE_VARIANT_MULTIPLE);
@@ -150,7 +158,8 @@ static void memkind_dax_kmem_closest_numanode_init(void)
 
 static void memkind_dax_kmem_preferred_closest_numanode_init(void)
 {
-    struct dax_numanode_t *g = &memkind_dax_kmem_numanode_g[NODE_VARIANT_SINGLE];
+    struct dax_numanode_t *g =
+        &memkind_dax_kmem_numanode_g[NODE_VARIANT_SINGLE];
     g->numanode = NULL;
     g->init_err = set_closest_numanode(memkind_dax_kmem_get_nodemask,
                                        &g->numanode, NODE_VARIANT_SINGLE);
@@ -202,7 +211,7 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_DAX_KMEM_OPS = {
     .malloc_usable_size = memkind_default_malloc_usable_size,
     .finalize = memkind_arena_finalize,
     .get_stat = memkind_arena_get_kind_stat,
-    .defrag_reallocate = memkind_arena_defrag_reallocate
+    .defrag_reallocate = memkind_arena_defrag_reallocate,
 };
 
 MEMKIND_EXPORT struct memkind_ops MEMKIND_DAX_KMEM_ALL_OPS = {
@@ -223,7 +232,7 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_DAX_KMEM_ALL_OPS = {
     .malloc_usable_size = memkind_default_malloc_usable_size,
     .finalize = memkind_arena_finalize,
     .get_stat = memkind_arena_get_kind_stat,
-    .defrag_reallocate = memkind_arena_defrag_reallocate
+    .defrag_reallocate = memkind_arena_defrag_reallocate,
 };
 
 MEMKIND_EXPORT struct memkind_ops MEMKIND_DAX_KMEM_PREFERRED_OPS = {
@@ -244,7 +253,7 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_DAX_KMEM_PREFERRED_OPS = {
     .malloc_usable_size = memkind_default_malloc_usable_size,
     .finalize = memkind_arena_finalize,
     .get_stat = memkind_arena_get_kind_stat,
-    .defrag_reallocate = memkind_arena_defrag_reallocate
+    .defrag_reallocate = memkind_arena_defrag_reallocate,
 };
 
 MEMKIND_EXPORT struct memkind_ops MEMKIND_DAX_KMEM_INTERLEAVE_OPS = {
@@ -265,5 +274,5 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_DAX_KMEM_INTERLEAVE_OPS = {
     .malloc_usable_size = memkind_default_malloc_usable_size,
     .finalize = memkind_arena_finalize,
     .get_stat = memkind_arena_get_kind_stat,
-    .defrag_reallocate = memkind_arena_defrag_reallocate
+    .defrag_reallocate = memkind_arena_defrag_reallocate,
 };
