@@ -1,29 +1,30 @@
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (C) 2016 - 2020 Intel Corporation.
+# Copyright (C) 2016 - 2021 Intel Corporation.
 
-import pytest
 import os
 import tempfile
 import subprocess
 
+
 class CMD_helper(object):
 
     def execute_cmd(self, command, sudo=False):
         if sudo:
             command = "sudo {0}".format(command)
-        #Initialize temp file for stdout. Will be removed when closed.
+        # Initialize temp file for stdout. Will be removed when closed.
         outfile = tempfile.SpooledTemporaryFile()
         try:
-            #Invoke process
-            p = subprocess.Popen(command, stdout=outfile, stderr=subprocess.STDOUT, shell=True)
+            # Invoke process
+            p = subprocess.Popen(
+                command, stdout=outfile, stderr=subprocess.STDOUT, shell=True)
             p.communicate()
-            #Read stdout from file
+            # Read stdout from file
             outfile.seek(0)
             stdout = outfile.read()
-        except:
+        except subprocess.CalledProcessError:
             raise
         finally:
-            #Make sure the file is closed
+            # Make sure the file is closed
             outfile.close()
         retcode = p.returncode
         return stdout.decode("utf-8"), retcode
